@@ -3,14 +3,12 @@
 
 require_relative 'test_utils'
 
-include TZInfo
-
-# Use send as a workaround for erroneous 'wrong number of arguments' errors with
-# JRuby 9.0.5.0 when calling methods with Java implementations. See #114.
-send(:using, TestUtils::TaintExt) if TestUtils.const_defined?(:TaintExt)
-
 class TCTimezone < Minitest::Test
+  include TZInfo
+
   class << self
+    include TZInfo
+
     private
 
     def time_with_unspecified_offset_test(method)
@@ -260,6 +258,7 @@ class TCTimezone < Minitest::Test
   end
 
   def test_get_tainted_loaded
+    skip_if_taint_is_undefined_or_no_op
     Timezone.get('Europe/Andorra')
 
     safe_test(unavailable: :skip) do
@@ -272,6 +271,7 @@ class TCTimezone < Minitest::Test
   end
 
   def test_get_tainted_and_frozen_loaded
+    skip_if_taint_is_undefined_or_no_op
     Timezone.get('Europe/Andorra')
 
     safe_test do
@@ -281,6 +281,8 @@ class TCTimezone < Minitest::Test
   end
 
   def test_get_tainted_not_previously_loaded
+    skip_if_taint_is_undefined_or_no_op
+
     safe_test(unavailable: :skip) do
       identifier = 'Europe/Andorra'.dup.taint
       assert(identifier.tainted?)
@@ -291,6 +293,8 @@ class TCTimezone < Minitest::Test
   end
 
   def test_get_tainted_and_frozen_not_previously_loaded
+    skip_if_taint_is_undefined_or_no_op
+
     safe_test do
       tz = Timezone.get('Europe/Amsterdam'.dup.taint.freeze)
       assert_equal('Europe/Amsterdam', tz.identifier)
