@@ -28,7 +28,12 @@ if COVERAGE_ENABLED && defined?(COVERAGE_TYPE)
     false
   end
 
-  feature_support = [['deduping_string_unary_minus', string_unary_minus_does_dedupe]].map do |feature, available|
+  untaint_is_functional = Object.new.respond_to?(:untaint) && RUBY_VERSION < '2.7'
+
+  feature_support = [
+    ['deduping_string_unary_minus', string_unary_minus_does_dedupe],
+    ['functional_untaint', untaint_is_functional]
+  ].map do |feature, available|
     "#{available ? '' : 'no_'}#{feature}"
   end
 
@@ -210,11 +215,11 @@ module TestUtils
     end
 
     def time(year, month, day, hour, minute, second, sub_second = 0, utc_offset = nil)
-      Timestamp.create(year, month, day, hour, minute, second, sub_second, utc_offset)
+      TZInfo::Timestamp.create(year, month, day, hour, minute, second, sub_second, utc_offset)
     end
 
     def time_with_offset(offset, year, month, day, hour, minute, second, sub_second = 0)
-      TimestampWithOffset.create(year, month, day, hour, minute, second, sub_second, offset.observed_utc_offset).set_timezone_offset(offset)
+      TZInfo::TimestampWithOffset.create(year, month, day, hour, minute, second, sub_second, offset.observed_utc_offset).set_timezone_offset(offset)
     end
   end
 
@@ -499,7 +504,7 @@ module TestUtils
     # equal.
     def assert_equal_with_offset_and_timezone_offset(expected, actual)
       assert_equal_with_offset(expected, actual)
-      assert_kind_of(TimezoneOffset, actual.timezone_offset)
+      assert_kind_of(TZInfo::TimezoneOffset, actual.timezone_offset)
       assert_equal(expected.timezone_offset, actual.timezone_offset)
     end
 
@@ -509,16 +514,23 @@ module TestUtils
       assert_equal_with_offset(expected, actual)
       assert_equal(expected.class, actual.class)
     end
-  end
 
-  # Object#taint is a deprecated no-op in Ruby 2.7 and outputs a warning. It
-  # will be removed in 3.2. Silence the warning or supply a replacement.
-  if TZInfo.const_defined?(:UntaintExt)
-    module TaintExt
-      refine Object do
-        def taint
-          self
+    # Object#taint is deprecated in Ruby >= 2.7 and will be removed in 3.2.
+    # 2.7 makes it a no-op with a warning.
+    # Define a method that will skip for use in tests that deal with tainted
+    # objects.
+    if Object.respond_to?(:taint)
+      if RUBY_VERSION >= '2.7'
+        def skip_if_taint_is_undefined_or_no_op
+          skip('Object#taint is a no-op')
         end
+      else
+        def skip_if_taint_is_undefined_or_no_op
+        end
+      end
+    else
+      def skip_if_taint_is_undefined_or_no_op
+        skip('Object#taint is not defined')
       end
     end
   end
