@@ -7,4 +7,4 @@ ENV['TZ'] = 'America/Los_Angeles'
 
 Dir[File.join(File.expand_path(File.dirname(__FILE__)), '**', 'tc_*.rb')].each {|t| require t}
 
-puts "Using #{DataSource.get}"
+puts "Using #{TZInfo::DataSource.get}"
